@@ -54,10 +54,16 @@ class Action():
         if log_user or log_interaction:
             import mongoengine
             dbname = config["bot"]["bot_name"]
-            with open("ca-certificate.crt", "w") as text_file:
-                text_file.write(os.getenv('DATABASE_CERT'))
-            mongoengine.connect(alias=dbname, host="mongodb+srv://" + os.getenv("DATABASE_USERNAME")+":" + os.getenv("DATABASE_PASSWORD") +
-                                "@" + os.getenv("DATABASE_HOST") + "/"+dbname+"?authSource=admin&tls=true&tlsCAFile=ca-certificate.crt")
+            if os.getenv('DATABASE_CERT', None):
+                # This can be remove in the future
+                with open("ca-certificate.crt", "w") as text_file:
+                    text_file.write(os.getenv('DATABASE_CERT'))
+                mongoengine.connect(alias=dbname, host="mongodb+srv://" + os.getenv("DATABASE_USERNAME")+":" + os.getenv("DATABASE_PASSWORD") +
+                                    "@" + os.getenv("DATABASE_HOST") + "/"+dbname+"?authSource=admin&tls=true&tlsCAFile=ca-certificate.crt")
+            else:
+                mongoengine.connect(alias=dbname, host="mongodb+srv://" + os.getenv("DATABASE_USERNAME")+":" + os.getenv("DATABASE_PASSWORD") +
+                                    "@" + os.getenv("DATABASE_HOST") + "/"+dbname+"?authSource=admin&tls=true")
+            
 
     def __call__(self, update: Update, context: CallbackContext):
         if self.log_user and not ("user_id" in context.user_data.keys()):
